@@ -5,5 +5,6 @@
 # The History Store (histore) is released under the Revised BSD License. See
 # file LICENSE for full license details.
 
-from histore.archive.base import Archive, PersistentArchive  # noqa: F401
-from histore.archive.manager.persist import PersistentArchiveManager  # noqa: F401, E501
+from histore.archive.base import Archive, PersistentArchive
+from histore.archive.manager.persist import PersistentArchiveManager
+from histore.document.base import InputDescriptor as Descriptor
